package com.goafanti.common.dao;

import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.springframework.ui.ModelMap;

import com.goafanti.common.model.ActivityUser;
import com.goafanti.common.model.ActivityUserKey;

public interface ActivityUserMapper {
	int deleteByPrimaryKey(ActivityUserKey key);

	int insert(ActivityUser record);

	int insertSelective(ActivityUser record);

	ActivityUser selectByPrimaryKey(ActivityUserKey key);

	int updateByPrimaryKeySelective(ActivityUser record);

	int updateByPrimaryKey(ActivityUser record);

	ActivityUser selectByUid(String uid);

	int batchDeleteByPrimaryKey(@Param("aid") Long aid, @Param("uid") String uid);

	ActivityUser selectByAidAndUid(@Param("aid") Long aid, @Param("uid") String uid);

	List<ModelMap> selectUserActivities(@Param("uid") String uid);
}